@@ -8,7 +8,11 @@ _cwd_Dir = do.Dir( do.get_cwd() )
 
 json_Path = do.Path( _cwd_Dir.join( 's3synchrony.json' ) )
 templates_Dir = do.Dir( _Dir.join( 'Templates' ) )
+platforms_Dir = do.Dir( _Dir.join( 'Platforms') )
 
-from . import DataPlatforms
+template_json_Path = do.Path( _Dir.join( 's3synchrony_template.json' ) )
+
+from .BasePlatform import BasePlatform
+from . import Platforms
 from . import Templates
 from .s3synchrony_main import *
